@@ -1,3 +1,6 @@
+#library(rlibkriging, lib.loc="bindings/R/Rlibs")
+#library(testthat)
+
 for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   context(paste0("Check predict 1D for kernel ",kernel))
 
@@ -6,7 +9,6 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
 #rlibkriging:::optim_log(3)
 #kernel="exp"
 
-
   f = function(x) 1-1/2*(sin(12*x)/(1+x)+2*cos(7*x)*x^5+0.7)
   #plot(f)
   n <- 5
@@ -22,7 +24,7 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   # m = as.list(r)
   
   ntest <- 100
-  Xtest <- as.matrix(runif(ntest))
+  Xtest <- as.matrix(c(X,runif(ntest)))
   ptest <- DiceKriging::predict(k,Xtest,type="UK",cov.compute = TRUE,checkNames=F)
   Yktest <- ptest$mean
   sktest <- ptest$sd
@@ -64,7 +66,7 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   #    lines(x,simulate(r,x=x,seed=i),col='grey')
   
   .x = seq(0.1,0.9,,11)
-  p_allx = predict(r,.x,TRUE, cov=FALSE, deriv=TRUE)
+  p_allx = predict(r,.x,TRUE, return_cov=FALSE, return_deriv=TRUE)
   for (i in 1:length(.x)) {
     # ref from DiceOptim::EI.grad
     newdata = .x[i]
@@ -98,7 +100,7 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
                                   (f.deltax - t(t(W)%*%u) ))
     kriging.sd.grad <- kriging.sd2.grad / (2*kriging.sd)
                        
-    p = predict(r,.x[i],TRUE, cov=FALSE, deriv=TRUE)
+    p = predict(r,.x[i],TRUE, return_cov=FALSE, return_deriv=TRUE)
   
     test_that(desc=paste0("vect pred mean deriv is ok:\n ",paste0(collapse=",",p_allx$mean_deriv[i]),"\n ",paste0(collapse=",",p$mean_deriv)),
              expect_equal(array(p_allx$mean_deriv[i]),array(p$mean_deriv),tol = precision))
