@@ -123,8 +123,10 @@ Kriging::KModel Kriging::make_Model(const arma::vec& theta, std::map<std::string
   auto t0 = Bench::tic();
   m.R = arma::mat(n, n, arma::fill::none);
   // check if we want to recompute model for same theta, for augmented Xy (using cholesky fast update).
-  bool update = (m_theta.size() == theta.size()) && (theta - m_theta).is_zero() && (this->m_T.memptr() != nullptr)
-                && (n > this->m_T.n_rows);
+  bool update = false;
+  if (!m_is_empty)
+    update = (m_theta.size() == theta.size()) && (theta - m_theta).is_zero() && (this->m_T.memptr() != nullptr)
+             && (n > this->m_T.n_rows);
   if (update) {
     m.L = LinearAlgebra::update_cholCov(&(m.R), m_dX, theta, _Cov, 1, Kriging::ones, m_T, m_R);
   } else
@@ -1056,7 +1058,7 @@ LIBKRIGING_EXPORT void Kriging::fit(const arma::vec& y,
       m_est_sigma2 = true;
 
     Kriging::KModel m = make_Model(m_theta, nullptr);
-
+    m_is_empty = false;
     m_T = std::move(m.L);
     m_R = std::move(m.R);
     m_M = std::move(m.Fstar);
@@ -1254,6 +1256,7 @@ LIBKRIGING_EXPORT void Kriging::fit(const arma::vec& y,
           m_est_theta = true;
           min_ofn = min_ofn_tmp;
 
+          m_is_empty = false;
           m_T = std::move(m.L);
           m_R = std::move(m.R);
           m_M = std::move(m.Fstar);
@@ -1358,6 +1361,7 @@ LIBKRIGING_EXPORT void Kriging::fit(const arma::vec& y,
           m_est_theta = true;
           min_ofn = min_ofn_tmp;
 
+          m_is_empty = false;
           m_T = std::move(m.L);
           m_R = std::move(m.R);
           m_M = std::move(m.Fstar);
@@ -2022,6 +2026,7 @@ Kriging Kriging::load(const std::string filename) {
   kr.m_est_theta = j["est_theta"].template get<decltype(kr.m_est_theta)>();
   kr.m_sigma2 = j["sigma2"].template get<decltype(kr.m_sigma2)>();
   kr.m_est_sigma2 = j["est_sigma2"].template get<decltype(kr.m_est_sigma2)>();
+  kr.m_is_empty = false;
 
   return kr;
 }
